"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("./utils");
const axios = require("axios");
class CodeStatsAPI {
    constructor(apiKey) {
        this.API_KEY = null;
        this.UPDATE_URL = "https://codestats.net/api/my/pulses";
        this.API_KEY = apiKey;
        if (this.API_KEY === null || this.API_KEY === undefined) {
            return;
        }
        this.axios = axios.default.create({
            baseURL: this.UPDATE_URL,
            timeout: 1000,
            headers: {
                "X-API-Token": this.API_KEY,
                "Content-Type": "application/json"
            }
        });
    }
    sendUpdate(pulse) {
        // tslint:disable-next-line:typedef
        const data = new ApiJSON(new Date());
        for (let lang of pulse.xps.keys()) {
            let languageName = utils_1.getLanguageName(lang);
            let xp = pulse.getXP(lang);
            data.xps.push(new ApiXP(languageName, xp));
        }
        let json = JSON.stringify(data);
        console.log(`JSON: ${json}`);
        this.axios.post(this.UPDATE_URL, json)
            .then((response) => {
            console.log(response);
        })
            .then(() => {
            pulse.reset();
        })
            .catch((error) => {
            console.log(error);
        });
    }
}
exports.CodeStatsAPI = CodeStatsAPI;
class ApiJSON {
    constructor(date) {
        this.coded_at = utils_1.getISOTimestamp(new Date());
        this.xps = new Array();
    }
}
class ApiXP {
    constructor(language, xp) {
        this.language = language;
        this.xp = xp;
    }
}
//# sourceMappingURL=code-stats-api.js.map