"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
// tslint:disable-next-line:max-line-length
const vscode_1 = require("vscode");
const pulse_1 = require("./pulse");
const code_stats_api_1 = require("./code-stats-api");
class XpCounter {
    constructor() {
        //    private languages: Array<string> = ["typescript", "javascript"];
        // wait 10s after each change in the document before sending an update
        this.UPDATE_DELAY = 10000;
        this.pulse = new pulse_1.Pulse();
        /*
        let allLanguages = languages.getLanguages().then(
            (result => {
                console.log(JSON.stringify(result));
            })
        );
        */
        let config = vscode_1.workspace.getConfiguration("codestats");
        if (!config) {
            return;
        }
        // tslint:disable-next-line:typedef
        let apiKey = config.get("apikey");
        this.api = new code_stats_api_1.CodeStatsAPI(`${apiKey}`);
        if (!this.statusBarItem) {
            this.statusBarItem = vscode_1.window.createStatusBarItem(vscode_1.StatusBarAlignment.Left);
        }
        let subscriptions = [];
        vscode_1.workspace.onDidChangeTextDocument(this.onTextDocumentChanged, this, subscriptions);
        this.combinedDisposable = vscode_1.Disposable.from(...subscriptions);
    }
    dispose() {
        this.combinedDisposable.dispose();
        this.statusBarItem.dispose();
    }
    onTextDocumentChanged(event) {
        let changeCount = 0;
        for (let change of event.contentChanges) {
            changeCount += this.determineChangeCount(change.range);
        }
        this.updateXpCount(event.document, changeCount);
    }
    determineChangeCount(range) {
        if (range === null || range === undefined) {
            return 0;
        }
        if (range.start.line === range.end.line) {
            if (range.start.character === range.end.character) {
                return 1;
            }
            else {
                return range.end.character - range.start.character;
            }
        }
        // multiline changes, copy/paste count as 1XP
        return 1;
    }
    updateXpCount(document, changeCount) {
        let show;
        if (this.isSupportedLanguage(document.languageId)) {
            this.pulse.addXP(document.languageId, changeCount);
            show = true;
        }
        else {
            show = false;
        }
        this.updateStatusBar(show, `${this.pulse.getXP(document.languageId)}`);
        // each change resets the timeout so we only send updates when there is a 10s delay in updates to the document
        if (this.updateTimeout !== null) {
            clearTimeout(this.updateTimeout);
        }
        this.updateTimeout = setTimeout(() => {
            this.api.sendUpdate(this.pulse);
        }, this.UPDATE_DELAY);
    }
    updateStatusBar(show, changeCount) {
        if (!show) {
            this.statusBarItem.hide();
        }
        else {
            this.statusBarItem.text = `$(pencil) C::S ${changeCount}`;
            this.statusBarItem.show();
        }
    }
    isSupportedLanguage(language) {
        // todo: check supported languages
        // only update xp if one of supported languages
        return true;
    }
}
exports.XpCounter = XpCounter;
//# sourceMappingURL=xp-counter.js.map